require "import"
import "android.content.Context"
import "android.content.Intent"
import "android.net.Uri"
import "android.view.View"
import "android.widget.EditText"
import "android.widget.GridView"
import "com.androlua.LuaDialog"
import "com.androlua.SingleLineAdapter"
import "java.lang.String"

local Symbol = {}
dir = package.searchpath("main", package.path):match("(.*)main.lua")
local path = dir .. "/data"

local function readSymbol(t, path)
    local file = io.open(path, "r")
    if file then
        for line in file:lines() do
            s = string.gsub(line, '\\n', '\n')
            s = s == "\\\\" and "\\" or s
            table.insert(t, s)
        end
        file:close()
    end
end

local function writeSymbol(t, path)
    local file = io.open(path, 'w')
    if file then
        for _, v in ipairs(t) do
            v = v == "\\" and "\\\\" or v
            file:write(string.gsub(v, '\n', '\\n') .. '\n')
        end
        file:close()
    end
end

local function moveItem(t, k, itemKey)
    local s = t[k + 1]
    if itemKey == 4 then
        table.insert(t, 1, s)
        table.remove(t, k + 2)
    elseif itemKey == 5 then
        table.remove(t, k + 1)
        table.insert(t, s)
    end
end

local function removeItem(t, k)
    table.remove(t, k)
end

local edit = loadlayout {
    EditText;
    hint = "Você pode inserir uma frase ou um caractere em várias linhas"
}
local et = LuaDialog()
et.setTitle("Adicionar")
et.setView(edit)
et.setButton("OK", function()
    if edit.text ~= '' then
        local confirmDialog = LuaDialog()
        confirmDialog.setTitle("Confirmar")
        confirmDialog.setMessage("Deseja salvar \"" .. edit.text .. "\"Na lista de emojis ou não?")
        confirmDialog.setPositiveButton("Salvar", function()
            table.insert(Symbol, edit.text)
            edit.text = ''
            writeSymbol(Symbol, path)
service.asyncSpeak("Emoji salvo com sucesso")
            grid.adapter = SingleLineAdapter(service, String(Symbol))
        end)
        confirmDialog.setNegativeButton("Cancelar", nil)
        confirmDialog.show()
    else
service.asyncSpeak(" Texto sem conteúdo")
  dlg.show()
    end
end)
et.setNegativeButton("Cancelar", nil)
local readme = LuaDialog(service)
readme.setTitle("Descrição")
readme.setMessage(    "Olá este é o widget de emojis.Foram adicionadas algumas categorias, caso queira mais emojis clique no botão adicionar")
readme.setButton2("Canal para baixar extensões, ferramentas e plugins", function()
    local intent = Intent(Intent.ACTION_VIEW, Uri.parse("https://t.me/tkmrcccmjsr"))
    service.startActivity(intent)
end)
readme.setButton("Sair", function()
    dlg.show()
end)

local menuItem = {
    "Copiar emoji",
    "Salvar emoji nos favoritos",
    "Compartilhar emoji",
    "Excluir emoji",
    "Mover Emoji para o topo",
    "Mover Emoji para baixo",
    "Editar emoji",
    "Sair",
}

local menuDlg = LuaDialog(service)
menuDlg.setItems(menuItem)

layout = {
    GridView,
    id = "grid",
    numColumns = 6,
    layout_width = "fill",
    layout_height = "fill",
}

dlg = LuaDialog(service)
dlg.View = loadlayout(layout)
readSymbol(Symbol, path)
grid.adapter = SingleLineAdapter(service, String(Symbol))
dlg.setButton("Sair")
dlg.setButton2("Mais", function(v)
    et.show()
end)
dlg.setButton3("Descrição", function(v)
    readme.show()
end)
dlg.setCancelable(false)

dlg.show()
grid.onItemClick = function(l, v)
    dlg.dismiss()
    service.pasteText(node, v.text)
    service.speak(v.text)
    return true
end

grid.onItemLongClick = function(l, v, p, i)
    dlg.dismiss()
    vibrator = this.getSystemService(Context.VIBRATOR_SERVICE)
    vibrator.vibrate(long{100, 30}, -1)
    menuDlg.show()
    menuDlg.onItemClick = function(_, _, itemKey)
        menuDlg.dismiss()
        if itemKey == 0 then
            service.copy(Symbol[i + 1])
service.asyncSpeak(" Emoji copiado com sucesso")
        elseif itemKey == 1 then
            service.addFavorites(Symbol[i + 1])
service.asyncSpeak(" Emoji salvo nos favoritos")
        elseif itemKey == 2 then
            local shareIntent = Intent(Intent.ACTION_SEND)
            shareIntent.setType("text/plain")
            shareIntent.putExtra(Intent.EXTRA_TEXT, Symbol[i + 1])
            service.startActivity(Intent.createChooser(shareIntent, "Compartilhar emoji"))
        elseif itemKey == 3 then
            LuaDialog(service)
                .setTitle("Excluir emoji")
                .setMessage("Tem certeza que deseja excluir este emoji?")
                .setButton("OK", function()
                    removeItem(Symbol, i + 1)
service.asyncSpeak("Emoji removido")
                    writeSymbol(Symbol, path)
                    grid.adapter = SingleLineAdapter(service, String(Symbol))
                    dlg.show()
                end)
                .setButton2("Cancelar", function()
                    menuDlg.show()
                end)
                .show()
        elseif itemKey == 4 then
            LuaDialog(service)
                .setTitle("Mover para o topo")
                .setMessage("Tem certeza que deseja mover este Emoji para o topo?")
                .setButton("OK", function()
                    moveItem(Symbol, i, itemKey)
service.asyncSpeak("Emoji movido para o topo")
                    writeSymbol(Symbol, path)
                    grid.adapter = SingleLineAdapter(service, String(Symbol))
                    dlg.show()
                end)
                .setButton2("Cancelar", function()
                    menuDlg.show()
                end)
                .show()
        elseif itemKey == 5 then
            LuaDialog(service)
                .setTitle("Mover para baixo")
                .setMessage("Tem certeza que deseja mover este Emoji para o final?")
                .setButton("OK", function()
                    moveItem(Symbol, i, itemKey)
service.asyncSpeak("Emoji movido para o final")
                    writeSymbol(Symbol, path)
                    grid.adapter = SingleLineAdapter(service, String(Symbol))
                    dlg.show()
                end)
                .setButton2("Cancelar", function()
                    menuDlg.show()
                end)
                .show()
elseif itemKey == 6 then
    local editDialog = LuaDialog(service)
    editDialog.setTitle("Editar emoji")
    editDialog.setView(EditText(service).setText(Symbol[i + 1]))
    editDialog.setPositiveButton("Salvar", function()
        local newText = editDialog.getView().getText().toString()
        table.remove(Symbol, i + 1)
        table.insert(Symbol, i + 1, newText)
        writeSymbol(Symbol, path)
        grid.adapter = SingleLineAdapter(service, String(Symbol))
        dlg.show()
        service.asyncSpeak("Emoji editado")
    end)
    editDialog.setNegativeButton("Cancelar", nil)
    editDialog.show()
        elseif itemKey == 7 then
            dlg.show()
        end
    end
end
